==> rWikiPathways_1.0.5.zip: rWikiPathways/doc/Overview.R <==
## ---- echo = FALSE---------------------------------------------------------
knitr::opts_chunk$set(
  eval=FALSE
)

## --------------------------------------------------------------------------
#  if(!"rWikiPathways" %in% installed.packages()){
#      source("https://bioconductor.org/biocLite.R")
#      biocLite("rWikiPathways")
#  }
#  library(rWikiPathways)

## --------------------------------------------------------------------------
#      listOrganisms()

## --------------------------------------------------------------------------
#      hs.pathways <- listPathways('Homo sapiens')
#      hs.pathways

## --------------------------------------------------------------------------
#      ?listPathways
#      length(hs.pathways)

## --------------------------------------------------------------------------
#      ?listPathwayIds
#      ?listPathwayNames
#      ?listPathwayUrls

## --------------------------------------------------------------------------
#      tnf.pathways <- findPathwaysByXref('TNF','H')
#      tnf.pathways

## --------------------------------------------------------------------------
#      ?findPathwayIdsByXref
#      ?findPathwayNamesByXref
#      ?findPathwayUrlsByXref

## --------------------------------------------------------------------------
#      getPathwayInfo('WP554')

## --------------------------------------------------------------------------
#      getXrefList('WP554','L')

## --------------------------------------------------------------------------
#      getXrefList('WP554', 'En')

## --------------------------------------------------------------------------
#      getXrefList('WP554', 'Ch')
#      getXrefList('WP554', 'Ce')
#      getXrefList('WP554', 'Cs')

## --------------------------------------------------------------------------
#      gpml <- getPathway('WP554')

## --------------------------------------------------------------------------
#      svg <- getColoredPathway('WP554')

## --------------------------------------------------------------------------
#      svg = getColoredPathway(pathway="WP554", graphId="ef1f3", color="DD88FF");

## --------------------------------------------------------------------------
#      downloadPathwayArchive()

## --------------------------------------------------------------------------
#      downloadPathwayArchive(organism="Mus musculus", format="gmt")

## --------------------------------------------------------------------------
#      downloadPathwayArchive(date="20171010", organism="Mus musculus", format="gmt")

## --------------------------------------------------------------------------
#      browseVignettes('rWikiPathways')
#      help(package='rWikiPathways')

==> rWikiPathways_1.2.1.zip: rWikiPathways/doc/Overview.R <==
## ---- echo = FALSE---------------------------------------------------------
knitr::opts_chunk$set(
  eval=FALSE
)

## --------------------------------------------------------------------------
#  if(!"rWikiPathways" %in% installed.packages()){
#      if (!requireNamespace("BiocManager", quietly=TRUE))
#          install.packages("BiocManager")
#      BiocManager::install("rWikiPathways")
#  }
#  library(rWikiPathways)

## --------------------------------------------------------------------------
#      listOrganisms()

## --------------------------------------------------------------------------
#      hs.pathways <- listPathways('Homo sapiens')
#      hs.pathways

## --------------------------------------------------------------------------
#      ?listPathways
#      length(hs.pathways)

## --------------------------------------------------------------------------
#      ?listPathwayIds
#      ?listPathwayNames
#      ?listPathwayUrls

## --------------------------------------------------------------------------
#      tnf.pathways <- findPathwaysByXref('TNF','H')
#      tnf.pathways

## --------------------------------------------------------------------------
#      ?findPathwayIdsByXref
#      ?findPathwayNamesByXref
#      ?findPathwayUrlsByXref

## --------------------------------------------------------------------------
#      getPathwayInfo('WP554')

## --------------------------------------------------------------------------
#      getXrefList('WP554','L')

## --------------------------------------------------------------------------
#      getXrefList('WP554', 'En')

## --------------------------------------------------------------------------
#      getXrefList('WP554', 'Ch')
#      getXrefList('WP554', 'Ce')
#      getXrefList('WP554', 'Cs')

## --------------------------------------------------------------------------
#      gpml <- getPathway('WP554')

## --------------------------------------------------------------------------
#      svg <- getColoredPathway('WP554')

## --------------------------------------------------------------------------
#      svg = getColoredPathway(pathway="WP554", graphId="ef1f3", color="DD88FF");

## --------------------------------------------------------------------------
#      downloadPathwayArchive()

## --------------------------------------------------------------------------
#      downloadPathwayArchive(organism="Mus musculus", format="gmt")

## --------------------------------------------------------------------------
#      downloadPathwayArchive(date="20171010", organism="Mus musculus", format="gmt")

## --------------------------------------------------------------------------
#      browseVignettes('rWikiPathways')
#      help(package='rWikiPathways')
